@@ -469,8 +469,9 @@ int OutputStream_write(T S, const void *b, int size) {
         assert(S);
         assert(b);
         S->sessionWritten = 0;
-        uchar_t *t = (uchar_t*)b;
-        while ((size-- > 0) && (write_byte(S, *t++) != -1));
+        for (uchar_t *t = (uchar_t*)b; (size-- > 0); t++)
+                if (write_byte(S, *t) < 0)
+                        break;
         return S->isclosed ? -1 : S->sessionWritten;
 }
 
