@@ -113,17 +113,6 @@ char *Str_toLower(char *s);
 char *Str_toUpper(char *s);
 
 
-/**
- * Converts a number to a string. The given <code>s</code> buffer
- * is returned with the string representation of <code>n</code>.
- * @param n The number (long) to convert to a string
- * @param s A buffer to write the string representation of <code>n</code>
- * into. The buffer must be of size 43 bytes or more
- * @return A pointer to <code>s</code>
- */
-char *Str_ton(long n, char s[43]);
-
-
 /**
  * Parses the string argument as a signed decimal integer.
  * @param s A string
@@ -419,4 +408,14 @@ unsigned int Str_hash(const void *x);
 int Str_cmp(const void *x, const void *y);
 
 
+/**
+ * Convert the numeric bytes value to a string representation scaled to
+ * human friendly storage unit [B, kB, MB, etc.].
+ * @param bytes Byte value to convert
+ * @param s A result buffer, must be large enough to hold 10 chars
+ * @return A pointer to s
+ */
+char *Str_bytesToSize(double bytes, char s[10]);
+
 #endif
+
