@@ -57,6 +57,7 @@
 #include "socket.h"
 #include "event.h"
 #include "system/Time.h"
+#include "exceptions/AssertException.h"
 
 
 /**
@@ -78,43 +79,98 @@ typedef enum {
 /* ----------------------------------------------------------------- Private */
 
 
-/*
- * This function waits for the process to change state. If the process state doesn't match the expectation,
- * a failed event is posted to notify the user. The time is saved on enter so in the case that the time steps
- * backwards/forwards, the wait_process will wait for absolute time and not stall or prematurely exit.
- * @param service A Service to wait for
- * @param expect A expected state (see Process_Status)
- * @return Either Process_Started if the process is running or Process_Stopped if it's not running
- */
-static Process_Status wait_process(Service_T s, Process_Status expect) {
-        int debug = Run.debug, isrunning = FALSE;
-        unsigned long now = time(NULL) * 1000, wait = 50;
-        assert(s->start || s->restart);
-        unsigned long timeout = (s->start ? s->start->timeout : s->restart->timeout) * 1000 + now;
-        ASSERT(s);
-        do {
-                Time_usleep(wait * USEC_PER_MSEC);
-                now += wait ;
-                wait = wait < 1000 ? wait * 2 : 1000; // double the wait during each cycle until 1s is reached
-                isrunning = Util_isProcessRunning(s, TRUE);
-                if ((expect == Process_Stopped && ! isrunning) || (expect == Process_Started && isrunning))
-                        break;
-                Run.debug = FALSE; // Turn off debug second time through to avoid flooding the log with pid file does not exist. This poll stuff here _will_ be refactored away
-        } while (now < timeout && ! Run.stopped);
-        Run.debug = debug; // restore the debug state
-        if (isrunning) {
-                if (expect == Process_Started)
-                        Event_post(s, Event_Exec, STATE_SUCCEEDED, s->action_EXEC, "started");
-                else
-                        Event_post(s, Event_Exec, STATE_FAILED, s->action_EXEC, "failed to stop");
-                return Process_Started;
-        } else {
-                if (expect == Process_Started)
-                        Event_post(s, Event_Exec, STATE_FAILED, s->action_EXEC, "failed to start");
-                else
-                        Event_post(s, Event_Exec, STATE_SUCCEEDED, s->action_EXEC, "stopped");
-                return Process_Stopped;
+static int _getOutput(InputStream_T in, char *buf, int buflen) {
+        InputStream_setTimeout(in, 0);
+        return InputStream_readBytes(in, buf, buflen - 1);
+}
+
+
+static int _commandExecute(Service_T S, command_t c, char *msg, int msglen, long *timeout) {
+        ASSERT(S);
+        ASSERT(c);
+        ASSERT(msg);
+        msg[0] = 0;
+        int status = -1;
+        Command_T C = NULL;
+        TRY
+        {
+                // May throw exception if the program doesn't exist (was removed while Monit was up)
+                C = Command_new(c->arg[0], NULL);
         }
+        ELSE
+        {
+                snprintf(msg, msglen, "Program %s failed: %s", c->arg[0], Exception_frame.message);
+        }
+        END_TRY;
+        if (C) {
+                for (int i = 1; i < c->length; i++)
+                        Command_appendArgument(C, c->arg[i]);
+                if (c->has_uid)
+                        Command_setUid(C, c->uid);
+                if (c->has_gid)
+                        Command_setGid(C, c->gid);
+                Command_setEnv(C, "MONIT_DATE", Time_string(Time_now(), (char[26]){}));
+                Command_setEnv(C, "MONIT_SERVICE", S->name);
+                Command_setEnv(C, "MONIT_HOST", Run.system->name);
+                Command_setEnv(C, "MONIT_EVENT", c == S->start ? "Started" : c == S->stop ? "Stopped" : "Restarted");
+                Command_setEnv(C, "MONIT_DESCRIPTION", c == S->start ? "Started" : c == S->stop ? "Stopped" : "Restarted");
+                if (S->type == TYPE_PROCESS) {
+                        Command_vSetEnv(C, "MONIT_PROCESS_PID", "%d", Util_isProcessRunning(S, FALSE));
+                        Command_vSetEnv(C, "MONIT_PROCESS_MEMORY", "%ld", S->inf->priv.process.mem_kbyte);
+                        Command_vSetEnv(C, "MONIT_PROCESS_CHILDREN", "%d", S->inf->priv.process.children);
+                        Command_vSetEnv(C, "MONIT_PROCESS_CPU_PERCENT", "%d", S->inf->priv.process.cpu_percent);
+                }
+                Process_T P = Command_execute(C);
+                Command_free(&C);
+                if (P) {
+                        do {
+                                Time_usleep(100000); // Check interval is 100ms
+                                *timeout -= 100000;
+                        } while ((status = Process_exitStatus(P)) < 0 && *timeout > 0 && ! Run.stopped);
+                        if (*timeout <= 0)
+                                snprintf(msg, msglen, "Program %s timed out", c->arg[0]);
+                        int n, total = 0;
+                        char buf[STRLEN];
+                        do {
+                                if ((n = _getOutput(Process_getErrorStream(P), buf, sizeof(buf))) <= 0)
+                                        n = _getOutput(Process_getInputStream(P), buf, sizeof(buf));
+                                if (n > 0) {
+                                        buf[n] = 0;
+                                        DEBUG("%s", buf);
+                                        // Report the first message (override existing plain timeout message if some program output is available)
+                                        if (! total)
+                                                snprintf(msg, msglen, "%s: %s%s", c->arg[0], *timeout <= 0 ? "Program timed out -- " : "", buf);
+                                        total += n;
+                                }
+                        } while (n > 0 && Run.debug && total < 2048); // Limit the debug output (if the program will have endless output, such as 'yes' utility, we have to stop at some point to not spin here forever)
+                        Process_free(&P); // Will kill the program if still running
+                }
+        }
+        return status;
+}
+
+
+static Process_Status _waitStart(Service_T s, long *timeout) {
+        long wait = 50000;
+        do {
+                if (Util_isProcessRunning(s, TRUE))
+                        return Process_Started;
+                Time_usleep(wait);
+                *timeout -= wait;
+                wait = wait < 1000000 ? wait * 2 : 1000000; // double the wait during each cycle until 1s is reached (Util_isProcessRunning can be heavy and we don't want to drain power every 100ms on mobile devices)
+        } while (*timeout > 0 && ! Run.stopped);
+        return Process_Stopped;
+}
+
+
+static Process_Status _waitStop(int pid, long *timeout) {
+        do {
+                if (! pid || (getpgid(pid) == -1 && errno != EPERM))
+                        return Process_Stopped;
+                Time_usleep(100000);
+                *timeout -= 100000;
+        } while (*timeout > 0 && ! Run.stopped);
+        return Process_Started;
 }
 
 
@@ -123,7 +179,7 @@ static Process_Status wait_process(Service_T s, Process_Status expect) {
  * that s depends on before starting s.
  * @param s A Service_T object
  */
-static void do_start(Service_T s) {
+static void _doStart(Service_T s) {
         ASSERT(s);
         if (s->visited)
                 return;
@@ -133,16 +189,19 @@ static void do_start(Service_T s) {
                 for (d = s->dependantlist; d; d = d->next ) {
                         Service_T parent = Util_getService(d->dependant);
                         ASSERT(parent);
-                        do_start(parent);
+                        _doStart(parent);
                 }
         }
         if (s->start) {
                 if (s->type != TYPE_PROCESS || ! Util_isProcessRunning(s, FALSE)) {
                         LogInfo("'%s' start: %s\n", s->name, s->start->arg[0]);
-                        spawn(s, s->start, NULL);
-                        /* We only wait for a process type, other service types does not have a pid file to watch */
-                        if (s->type == TYPE_PROCESS)
-                                wait_process(s, Process_Started);
+                        char msg[STRLEN];
+                        long timeout = s->start->timeout * USEC_PER_SEC;
+                        int status = _commandExecute(s, s->start, msg, sizeof(msg), &timeout);
+                        if ((s->type == TYPE_PROCESS && _waitStart(s, &timeout) != Process_Started) || status < 0)
+                                Event_post(s, Event_Exec, STATE_FAILED, s->action_EXEC, "failed to start (exit status %d) -- %s", status, *msg ? msg : "no output");
+                        else
+                                Event_post(s, Event_Exec, STATE_SUCCEEDED, s->action_EXEC, "started");
                 }
         } else {
                 LogDebug("'%s' start skipped -- method not defined\n", s->name);
@@ -157,7 +216,7 @@ static void do_start(Service_T s) {
  * @param flag TRUE if the monitoring should be disabled or FALSE if monitoring should continue (when stop is part of restart)
  * @return TRUE if the service was stopped otherwise FALSE
  */
-static int do_stop(Service_T s, int flag) {
+static int _doStop(Service_T s, int flag) {
         int rv = TRUE;
         ASSERT(s);
         if (s->depend_visited)
@@ -166,9 +225,16 @@ static int do_stop(Service_T s, int flag) {
         if (s->stop) {
                 if (s->type != TYPE_PROCESS || Util_isProcessRunning(s, FALSE)) {
                         LogInfo("'%s' stop: %s\n", s->name, s->stop->arg[0]);
-                        spawn(s, s->stop, NULL);
-                        if (s->type == TYPE_PROCESS && (wait_process(s, Process_Stopped) != Process_Stopped)) // Only wait for process service types stop
+                        char msg[STRLEN];
+                        long timeout = s->stop->timeout * USEC_PER_SEC;
+                        int pid = Util_isProcessRunning(s, TRUE);
+                        int status = _commandExecute(s, s->stop, msg, sizeof(msg), &timeout);
+                        if ((s->type == TYPE_PROCESS && _waitStop(pid, &timeout) != Process_Stopped) || status < 0) {
                                 rv = FALSE;
+                                Event_post(s, Event_Exec, STATE_FAILED, s->action_EXEC, "failed to stop (exit status %d) -- %s", status, *msg ? msg : "no output");
+                        } else {
+                                Event_post(s, Event_Exec, STATE_SUCCEEDED, s->action_EXEC, "stopped");
+                        }
                 }
         } else {
                 LogDebug("'%s' stop skipped -- method not defined\n", s->name);
@@ -186,13 +252,17 @@ static int do_stop(Service_T s, int flag) {
  * This function simply restarts the service s.
  * @param s A Service_T object
  */
-static void do_restart(Service_T s) {
+static void _doRestart(Service_T s) {
         if (s->restart) {
                 LogInfo("'%s' restart: %s\n", s->name, s->restart->arg[0]);
-                spawn(s, s->restart, NULL);
-                /* We only wait for a process type, other service types does not have a pid file to watch */
-                if (s->type == TYPE_PROCESS)
-                        wait_process(s, Process_Started);
+                Util_resetInfo(s);
+                char msg[STRLEN];
+                long timeout = s->restart->timeout * USEC_PER_SEC;
+                int status = _commandExecute(s, s->restart, msg, sizeof(msg), &timeout);
+                if ((s->type == TYPE_PROCESS && _waitStart(s, &timeout) != Process_Started) || status < 0)
+                        Event_post(s, Event_Exec, STATE_FAILED, s->action_EXEC, "failed to restart (exit status %d) -- %s", status, msg);
+                else
+                        Event_post(s, Event_Exec, STATE_SUCCEEDED, s->action_EXEC, "restarted");
         } else {
                 LogDebug("'%s' restart skipped -- method not defined\n", s->name);
         }
@@ -206,7 +276,7 @@ static void do_restart(Service_T s) {
  * @param s A Service_T object
  * @param flag A Custom flag
  */
-static void do_monitor(Service_T s, int flag) {
+static void _doMonitor(Service_T s, int flag) {
         ASSERT(s);
         if (s->visited)
                 return;
@@ -216,7 +286,7 @@ static void do_monitor(Service_T s, int flag) {
                 for (d = s->dependantlist; d; d = d->next ) {
                         Service_T parent = Util_getService(d->dependant);
                         ASSERT(parent);
-                        do_monitor(parent, flag);
+                        _doMonitor(parent, flag);
                 }
         }
         Util_monitorSet(s);
@@ -228,7 +298,7 @@ static void do_monitor(Service_T s, int flag) {
  * @param s A Service_T object
  * @param flag A Custom flag
  */
-static void do_unmonitor(Service_T s, int flag) {
+static void _doUnmonitor(Service_T s, int flag) {
         ASSERT(s);
         if (s->depend_visited)
                 return;
@@ -247,7 +317,7 @@ static void do_unmonitor(Service_T s, int flag) {
  * @param action An action to do on the dependant services
  * @param flag A Custom flag
  */
-static void do_depend(Service_T s, int action, int flag) {
+static void _doDepend(Service_T s, int action, int flag) {
         Service_T child;
         ASSERT(s);
         for (child = servicelist; child; child = child->next) {
@@ -256,14 +326,14 @@ static void do_depend(Service_T s, int action, int flag) {
                         for (d = child->dependantlist; d; d = d->next) {
                                 if (IS(d->dependant, s->name)) {
                                         if (action == ACTION_START)
-                                                do_start(child);
+                                                _doStart(child);
                                         else if (action == ACTION_MONITOR)
-                                                do_monitor(child, flag);
-                                        do_depend(child, action, flag);
+                                                _doMonitor(child, flag);
+                                        _doDepend(child, action, flag);
                                         if (action == ACTION_STOP)
-                                                do_stop(child, flag);
+                                                _doStop(child, flag);
                                         else if (action == ACTION_UNMONITOR)
-                                                do_unmonitor(child, flag);
+                                                _doUnmonitor(child, flag);
                                         break;
                                 }
                         }
@@ -307,16 +377,16 @@ int control_service_daemon(const char *S, const char *action) {
         if (socket_print(socket,
                 "POST /%s HTTP/1.0\r\n"
                 "Content-Type: application/x-www-form-urlencoded\r\n"
-                "Content-Length: %d\r\n"
+                "Content-Length: %lu\r\n"
                 "%s"
                 "\r\n"
                 "action=%s",
                 S,
-                strlen("action=") + strlen(action),
+                (unsigned long)(strlen("action=") + strlen(action)),
                 auth ? auth : "",
                 action) < 0)
         {
-                LogError("Cannot send the command '%s' to the monit daemon -- %s", action ? action : "null", STRERROR);
+                LogError("Cannot send the command '%s' to the monit daemon -- %s\n", action ? action : "null", STRERROR);
                 goto err1;
         }
 
@@ -397,27 +467,27 @@ int control_service(const char *S, int A) {
         }
         switch(A) {
                 case ACTION_START:
-                        do_depend(s, ACTION_STOP, FALSE);
-                        do_start(s);
-                        do_depend(s, ACTION_START, 0);
+                        _doDepend(s, ACTION_STOP, FALSE);
+                        _doStart(s);
+                        _doDepend(s, ACTION_START, 0);
                         break;
 
                 case ACTION_STOP:
-                        do_depend(s, ACTION_STOP, TRUE);
-                        do_stop(s, TRUE);
+                        _doDepend(s, ACTION_STOP, TRUE);
+                        _doStop(s, TRUE);
                         break;
 
                 case ACTION_RESTART:
                         LogInfo("'%s' trying to restart\n", s->name);
-                        do_depend(s, ACTION_STOP, FALSE);
+                        _doDepend(s, ACTION_STOP, FALSE);
                         if (s->restart) {
-                                do_restart(s);
-                                do_depend(s, ACTION_START, 0);
+                                _doRestart(s);
+                                _doDepend(s, ACTION_START, 0);
                         } else {
-                                if (do_stop(s, FALSE)) {
+                                if (_doStop(s, FALSE)) {
                                         /* Only start if stop succeeded */
-                                        do_start(s);
-                                        do_depend(s, ACTION_START, 0);
+                                        _doStart(s);
+                                        _doDepend(s, ACTION_START, 0);
                                 } else {
                                         /* enable monitoring of this service again to allow the restart retry in the next cycle up to timeout limit */
                                         Util_monitorSet(s);
@@ -427,17 +497,17 @@ int control_service(const char *S, int A) {
 
                 case ACTION_MONITOR:
                         /* We only enable monitoring of this service and all prerequisite services. Chain of services which depends on this service keep its state */
-                        do_monitor(s, 0);
+                        _doMonitor(s, 0);
                         break;
 
                 case ACTION_UNMONITOR:
                         /* We disable monitoring of this service and all services which depends on it */
-                        do_depend(s, ACTION_UNMONITOR, 0);
-                        do_unmonitor(s, 0);
+                        _doDepend(s, ACTION_UNMONITOR, 0);
+                        _doUnmonitor(s, 0);
                         break;
 
                 default:
-                        LogError("Service '%s' -- invalid action %s\n", S, A);
+                        LogError("Service '%s' -- invalid action %d\n", S, A);
                         return FALSE;
         }
         return TRUE;
