@@ -57,31 +57,21 @@
 #include "monit.h"
 #include "device_sysdep.h"
 
-/**
- * AIX special block device mountpoint method. Filesystem must be mounted.
- * In the case of success, mountpoint is stored in filesystem information
- * structure for later use.
- *
- * @param inf      Information structure
- * @param blockdev Identifies block special device
- * @return         NULL
- */
-char *device_mountpoint_sysdep(Info_T inf, char *blockdev) {
+char *device_mountpoint_sysdep(char *dev, char *buf, int buflen) {
   struct mntent *mnt;
   FILE          *mntfd;
 
-  ASSERT(inf);
-  ASSERT(blockdev);
+  ASSERT(dev);
 
   if ((mntfd = setmntent("/etc/mtab", "r")) == NULL) {
     LogError("Cannot open /etc/mtab file\n");
     return NULL;
   }
   while ((mnt = getmntent(mntfd)) != NULL) {
-    if (IS(blockdev, mnt->mnt_fsname)) {
+    if (IS(dev, mnt->mnt_fsname)) {
       endmntent(mntfd);
-      inf->priv.filesystem.mntpath = Str_dup(mnt->mnt_dir);
-      return inf->priv.filesystem.mntpath;
+      snprintf(buf, buflen, "%s", mnt->mnt_dir);
+      return buf;
     }
   }
   endmntent(mntfd);
@@ -89,20 +79,13 @@ char *device_mountpoint_sysdep(Info_T inf, char *blockdev) {
 }
 
 
-/**
- * AIX filesystem usage statistics. In the case of success result is stored in
- * given information structure.
- *
- * @param inf Information structure
- * @return    FALSE
- */
-int filesystem_usage_sysdep(Info_T inf) {
+int filesystem_usage_sysdep(char *mntpoint, Info_T inf) {
   struct statfs usage;
 
   ASSERT(inf);
 
-  if (statfs(inf->priv.filesystem.mntpath, &usage) != 0) {
-    LogError("Error getting usage statistics for filesystem '%s' -- %s\n", inf->priv.filesystem.mntpath, STRERROR);
+  if (statfs(mntpoint, &usage) != 0) {
+    LogError("Error getting usage statistics for filesystem '%s' -- %s\n", mntpoint, STRERROR);
     return FALSE;
   }
   inf->priv.filesystem.f_bsize =           usage.f_bsize;
