@@ -57,63 +57,46 @@
 #include "monit.h"
 #include "device_sysdep.h"
 
-/**
- * MacOS X special block device mountpoint method. Filesystem must be mounted.
- * In the case of success, mountpoint is stored in filesystem information
- * structure for later use.
- *
- * @param inf      Information structure where resulting data will be stored
- * @param blockdev Identifies block special device
- * @return         NULL in the case of failure otherwise mountpoint
- */
-char *device_mountpoint_sysdep(Info_T inf, char *blockdev) {
+char *device_mountpoint_sysdep(char *dev, char *buf, int buflen) {
   int countfs;
 
-  ASSERT(inf);
-  ASSERT(blockdev);
+  ASSERT(dev);
 
   if ((countfs = getfsstat(NULL, 0, MNT_NOWAIT)) != -1) {
     struct statfs *statfs = CALLOC(countfs, sizeof(struct statfs));
     if ((countfs = getfsstat(statfs, countfs * sizeof(struct statfs), MNT_NOWAIT)) != -1) {
-      int i;
-      for (i = 0; i < countfs; i++) {
+      for (int i = 0; i < countfs; i++) {
         struct statfs *sfs = statfs + i;
-        if (IS(sfs->f_mntfromname, blockdev)) {
-          inf->priv.filesystem.mntpath = Str_dup(sfs->f_mntonname);
+        if (IS(sfs->f_mntfromname, dev)) {
+          snprintf(buf, buflen, "%s", sfs->f_mntonname);
           FREE(statfs);
-          return inf->priv.filesystem.mntpath;
+          return buf;
         }
       }
     }
     FREE(statfs);
   }
-  LogError("Error getting mountpoint for filesystem '%s' -- %s\n", blockdev, STRERROR);
+  LogError("Error getting mountpoint for filesystem '%s' -- %s\n", dev, STRERROR);
   return NULL;
 }
 
 
-/**
- * MacOS X filesystem usage statistics. In the case of success result is stored in
- * given information structure.
- *
- * @param inf Information structure where resulting data will be stored
- * @return    TRUE if informations were succesfully read otherwise FALSE
- */
-int filesystem_usage_sysdep(Info_T inf) {
+int filesystem_usage_sysdep(char *mntpoint, Info_T inf) {
   struct statfs usage;
 
   ASSERT(inf);
 
-  if (statfs(inf->priv.filesystem.mntpath, &usage) != 0) {
-    LogError("Error getting usage statistics for filesystem '%s' -- %s\n", inf->priv.filesystem.mntpath, STRERROR);
+  if (statfs(mntpoint, &usage) != 0) {
+    LogError("Error getting usage statistics for filesystem '%s' -- %s\n", mntpoint, STRERROR);
     return FALSE;
   }
   inf->priv.filesystem.f_bsize =           usage.f_bsize;
-  inf->priv.filesystem.f_blocks =          (long)usage.f_blocks;
-  inf->priv.filesystem.f_blocksfree =      (long)usage.f_bavail;
-  inf->priv.filesystem.f_blocksfreetotal = (long)usage.f_bfree;
-  inf->priv.filesystem.f_files =           (long)usage.f_files;
-  inf->priv.filesystem.f_filesfree =       (long)usage.f_ffree;
+  inf->priv.filesystem.f_blocks =          usage.f_blocks;
+  inf->priv.filesystem.f_blocksfree =      usage.f_bavail;
+  inf->priv.filesystem.f_blocksfreetotal = usage.f_bfree;
+  inf->priv.filesystem.f_files =           usage.f_files;
+  inf->priv.filesystem.f_filesfree =       usage.f_ffree;
+  inf->priv.filesystem._flags =            inf->priv.filesystem.flags;
   inf->priv.filesystem.flags =             usage.f_flags;
   return TRUE;
 }
