@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 /**
@@ -95,12 +95,12 @@ int read_proc_file(char *buf, int buf_size, char *name, int pid, int *bytes_read
                 snprintf(filename, STRLEN, "/proc/%d/%s", pid, name);
 
         if ((fd = open(filename, O_RDONLY)) < 0) {
-                DEBUG("%s: Cannot open proc file %s -- %s\n", prog, filename, STRERROR);
+                DEBUG("Cannot open proc file %s -- %s\n", filename, STRERROR);
                 return rv;
         }
 
         if ((bytes = (int)read(fd, buf, buf_size-1)) < 0) {
-                DEBUG("%s: Cannot read proc file %s -- %s\n", prog, filename, STRERROR);
+                DEBUG("Cannot read proc file %s -- %s\n", filename, STRERROR);
                 goto error;
         }
         if (bytes_read)
@@ -112,7 +112,7 @@ int read_proc_file(char *buf, int buf_size, char *name, int pid, int *bytes_read
 
 error:
         if (close(fd) < 0)
-                LogError("%s: Socket close failed -- %s\n", prog, STRERROR);
+                LogError("Socket close failed -- %s\n", STRERROR);
 
         return rv;
 }
@@ -121,7 +121,7 @@ error:
  * Get the actual time as a floating point number
  * @return time in seconds
  */
-double get_float_time(void) {    
+double get_float_time(void) {
         struct timeval t;
 
         gettimeofday(&t, NULL);
@@ -179,6 +179,6 @@ void fillprocesstree(ProcessTree_T *pt, int index) {
                 parent_pt->mem_kbyte_sum   += pt[index].mem_kbyte_sum;
                 parent_pt->cpu_percent_sum += pt[index].cpu_percent_sum;
                 parent_pt->cpu_percent_sum  = (pt[index].cpu_percent_sum > 1000) ? 1000 : parent_pt->cpu_percent_sum;
-        } 
+        }
 }
 
