@@ -146,12 +146,12 @@ int initprocesstree_sysdep(ProcessTree_T ** reference) {
   static struct kinfo_proc2 *pinfo;
 
   if (sysctl(mib_maxslp, 2, &maxslp, &size, NULL, 0) < 0) {
-    LogError("system statistic error -- vm.maxslp failed");
+    LogError("system statistic error -- vm.maxslp failed\n");
     return FALSE;
   }
 
   if (sysctl(mib_proc2, 6, NULL, &size, NULL, 0) == -1) {
-    LogError("system statistic error -- kern.proc2 #1 failed");
+    LogError("system statistic error -- kern.proc2 #1 failed\n");
     return FALSE;
   }
 
@@ -160,7 +160,7 @@ int initprocesstree_sysdep(ProcessTree_T ** reference) {
   mib_proc2[5] = (int)(size / sizeof(struct kinfo_proc2));
   if (sysctl(mib_proc2, 6, pinfo, &size, NULL, 0) == -1) {
     FREE(pinfo);
-    LogError("system statistic error -- kern.proc2 #2 failed");
+    LogError("system statistic error -- kern.proc2 #2 failed\n");
     return FALSE;
   }
 
@@ -171,7 +171,7 @@ int initprocesstree_sysdep(ProcessTree_T ** reference) {
   if (! (kvm_handle = kvm_openfiles(NULL, NULL, NULL, KVM_NO_FILES, buf))) {
     FREE(pinfo);
     FREE(pt);
-    LogError("system statistic error -- kvm_openfiles failed: %s", buf);
+    LogError("system statistic error -- kvm_openfiles failed: %s\n", buf);
     return FALSE;
   }
 
