@@ -19,27 +19,15 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 #include "config.h"
 
-#ifdef HAVE_STDIO_H
-#include <stdio.h>
-#endif
-
-#ifdef HAVE_ERRNO_H
-#include <errno.h>
-#endif
-
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
 
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-
 #include "protocol.h"
 
 /**
@@ -51,24 +39,24 @@
 int check_clamav(Socket_T socket) {
 
   char buf[STRLEN];
-  const char *ok= "PONG";
+  const char *ok = "PONG";
 
   ASSERT(socket);
 
   if(socket_print(socket, "PING\r\n") < 0) {
-    socket_setError(socket, "CLAMAV: error sending data -- %s\n", STRERROR);
+    socket_setError(socket, "CLAMAV: error sending data -- %s", STRERROR);
     return FALSE;
   }
 
   if(!socket_readln(socket, buf, sizeof(buf))) {
-    socket_setError(socket, "CLAMAV: error receiving data -- %s\n", STRERROR);
+    socket_setError(socket, "CLAMAV: error receiving data -- %s", STRERROR);
     return FALSE;
   }
 
   Str_chomp(buf);
 
   if(strncasecmp(buf, ok, strlen(ok)) != 0) {
-    socket_setError(socket, "CLAMAV error: %s\n", buf);
+    socket_setError(socket, "CLAMAV error: %s", buf);
     return FALSE;
   }
 
