@@ -19,19 +19,11 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 #include "config.h"
 
-#ifdef HAVE_STDIO_H
-#include <stdio.h>
-#endif
-
-#ifdef HAVE_ERRNO_H
-#include <errno.h>
-#endif
-
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
@@ -58,51 +50,51 @@ int check_ldap2(Socket_T socket) {
   unsigned char buf[STRLEN];
 
   unsigned char request[14] = {
-    0x30,	                 /** Universal Sequence TAG */
-    0x0c,	       /** Length of the packet's data part */
+    0x30,                         /** Universal Sequence TAG */
+    0x0c,               /** Length of the packet's data part */
 
-    0x02,	                  /** Universal Integer TAG */
-    0x01,			   	 /** Integer length */
-    0x00,		   	              /** MessageID */
+    0x02,                          /** Universal Integer TAG */
+    0x01,                                    /** Integer length */
+    0x00,                                         /** MessageID */
 
-    0x60,		    /** Application BindRequest TAG */
-    0x07,		        /** Length of the data part */
+    0x60,                    /** Application BindRequest TAG */
+    0x07,                        /** Length of the data part */
 
     0x02,                         /** Universal Integer TAG */
-    0x01,			         /** Integer length */
-    0x02,			       /** Protocol version */	
+    0x01,                                 /** Integer length */
+    0x02,                               /** Protocol version */
 
     0x04,                    /** Universal Octet string TAG */
-    0x00,      			    /** Octet string length */
-    /* NULL */     	     	       /** Anonymous BindDN */
+    0x00,                                  /** Octet string length */
+    /* NULL */                                 /** Anonymous BindDN */
 
-    0x80,	        /** Context specific SimpleAuth TAG */
-    0x00     	       /** SimpleAuth (octet string) length */
-    /* NULL */     	     	  /** Anonymous Credentials */
+    0x80,                /** Context specific SimpleAuth TAG */
+    0x00                    /** SimpleAuth (octet string) length */
+    /* NULL */                            /** Anonymous Credentials */
   };
 
   unsigned char response[14] = {
-    0x30,	                 /** Universal Sequence TAG */
-    0x0c,	       /** Length of the packet's data part */
+    0x30,                         /** Universal Sequence TAG */
+    0x0c,               /** Length of the packet's data part */
 
-    0x02,	                  /** Universal Integer TAG */
-    0x01,			   	 /** Integer length */
-    0x00,		   	              /** MessageID */
+    0x02,                          /** Universal Integer TAG */
+    0x01,                                    /** Integer length */
+    0x00,                                         /** MessageID */
 
-    0x61,		   /** Application BindResponse TAG */
-    0x07,		        /** Length of the data part */
+    0x61,                   /** Application BindResponse TAG */
+    0x07,                        /** Length of the data part */
 
     0x0a,                      /** Universal Enumerated TAG */
-    0x01,			      /** Enumerated length */
-    0x00,			                /** Success */	
+    0x01,                              /** Enumerated length */
+    0x00,                                        /** Success */
 
     0x04,                    /** Universal Octet string TAG */
-    0x00,      			    /** Octet string length */
-    /* NULL */     	     	              /** MatchedDN */
+    0x00,                                  /** Octet string length */
+    /* NULL */                                        /** MatchedDN */
 
     0x04,                    /** Universal Octet string TAG */
-    0x00      			    /** Octet string length */
-    /* NULL */     	     	           /** ErrorMessage */
+    0x00                                  /** Octet string length */
+    /* NULL */                                     /** ErrorMessage */
   };
 
   unsigned char unbind[7] = {
@@ -123,24 +115,24 @@ int check_ldap2(Socket_T socket) {
 
 
   if(socket_write(socket, (unsigned char *)request, sizeof(request)) < 0) {
-    socket_setError(socket, "LDAP: error sending data -- %s\n", STRERROR);
+    socket_setError(socket, "LDAP: error sending data -- %s", STRERROR);
     return FALSE;
   }
 
   if(socket_read(socket, (unsigned char *)buf, sizeof(response)) <= 0) {
-    socket_setError(socket, "LDAP: error receiving data -- %s\n", STRERROR);
+    socket_setError(socket, "LDAP: error receiving data -- %s", STRERROR);
     return FALSE;
   }
 
   if(memcmp((unsigned char *)buf,
-	    (unsigned char *)response,
-	    sizeof(response))) {
-    socket_setError(socket, "LDAP: anonymous bind failed\n");
+            (unsigned char *)response,
+            sizeof(response))) {
+    socket_setError(socket, "LDAP: anonymous bind failed");
     return FALSE;
   }
 
   if(socket_write(socket, (unsigned char *)unbind, sizeof(unbind)) < 0) {
-    socket_setError(socket, "LDAP: error sending data -- %s\n", STRERROR);
+    socket_setError(socket, "LDAP: error sending data -- %s", STRERROR);
     return FALSE;
   }
 
