@@ -17,14 +17,6 @@
 
 #include "config.h"
 
-#ifdef HAVE_STDIO_H
-#include <stdio.h>
-#endif
-
-#ifdef HAVE_ERRNO_H
-#include <errno.h>
-#endif
-
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
@@ -38,7 +30,7 @@
 static int do_send(Socket_T socket, char *msg) {
 
         if(socket_write(socket, msg, strlen(msg)) < 0) {
-                socket_setError(socket, "LMTP: error sending data -- %s\n", STRERROR);
+                socket_setError(socket, "LMTP: error sending data -- %s", STRERROR);
                 return FALSE;
         }
 
@@ -53,7 +45,7 @@ static int expect(Socket_T socket, int expect, int log) {
         char buf[STRLEN];
 
         if(!socket_readln(socket, buf, STRLEN)) {
-                socket_setError(socket, "LMTP: error receiving data -- %s\n", STRERROR);
+                socket_setError(socket, "LMTP: error receiving data -- %s", STRERROR);
                 return FALSE;
         }
 
@@ -61,8 +53,8 @@ static int expect(Socket_T socket, int expect, int log) {
 
         sscanf(buf, "%d%*s", &status);
         if(status != expect) {
-                if(log) 
-                        socket_setError(socket, "LMTP error: %s\n", buf);
+                if(log)
+                        socket_setError(socket, "LMTP error: %s", buf);
                 return FALSE;
         }
 
