@@ -19,40 +19,15 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 #include "config.h"
 
-#ifdef HAVE_STDIO_H
-#include <stdio.h>
-#endif
-
-#ifdef HAVE_ERRNO_H
-#include <errno.h>
-#endif
-
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
-#ifdef HAVE_SYS_SOCKET_H
-#include <sys/socket.h>
-#endif
-
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
 
-#ifdef HAVE_NETINET_IN_H
-#include <netinet/in.h>
-#endif
-
-#ifdef HAVE_ARPA_INET_H
-#include <arpa/inet.h>
-#endif
-
-
 #include "protocol.h"
 
 /**
@@ -86,19 +61,19 @@ int check_postfix_policy(Socket_T socket) {
     "client_address=1.2.3.4\n"
     "client_name=mx.foo.tld\n"
     "\n") < 0) {
-    socket_setError(socket, "POSTFIX-POLICY: error sending data -- %s\n", STRERROR);
+    socket_setError(socket, "POSTFIX-POLICY: error sending data -- %s", STRERROR);
     return FALSE;
   }
 
   if(! socket_readln(socket, buf, sizeof(buf))) {
-    socket_setError(socket, "POSTFIX-POLICY: error receiving data -- %s\n", STRERROR);
+    socket_setError(socket, "POSTFIX-POLICY: error receiving data -- %s", STRERROR);
     return FALSE;
   }
 
   Str_chomp(buf);
 
   if( (strlen(buf) <= 7) || strncasecmp(buf, "action=", 7) ) {
-    socket_setError(socket, "POSTFIX-POLICY error: %s\n",
+    socket_setError(socket, "POSTFIX-POLICY error: %s",
       *buf?buf:"no action returned");
     return FALSE;
   }
