@@ -19,24 +19,15 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 #include "config.h"
-#include <ctype.h>
 
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
 
-#ifdef HAVE_STDIO_H
-#include <stdio.h>
-#endif
-
-#ifdef HAVE_ERRNO_H
-#include <errno.h>
-#endif
-
 #include "protocol.h"
 
 /**
@@ -56,42 +47,42 @@ int check_rsync(Socket_T socket) {
 
   /* Read and check the greeting */
   if (!socket_readln(socket, buf, sizeof(buf))) {
-    socket_setError(socket, "RSYNC: did not see server greeting  -- %s\n", STRERROR);
+    socket_setError(socket, "RSYNC: did not see server greeting  -- %s", STRERROR);
     return FALSE;
   }
   Str_chomp(buf);
   rc = sscanf(buf, "%10s %d.%d", header, &version_major, &version_minor);
   if ((rc == EOF) || (rc != 3)) {
-    socket_setError(socket, "RSYNC: server greeting parse error %s\n", buf);
+    socket_setError(socket, "RSYNC: server greeting parse error %s", buf);
     return FALSE;
   }
   if (strncasecmp(header, rsyncd, strlen(rsyncd)) != 0) {
-    socket_setError(socket, "RSYNC: server sent unexpected greeting -- %s\n", buf);
+    socket_setError(socket, "RSYNC: server sent unexpected greeting -- %s", buf);
     return FALSE;
   }
 
   /* Send back the greeting */
   if (socket_print(socket, "%s\n", buf) <= 0) {
-    socket_setError(socket, "RSYNC: identification string send failed -- %s\n", STRERROR);
+    socket_setError(socket, "RSYNC: identification string send failed -- %s", STRERROR);
     return FALSE;
   }
 
   /* Send #list command */
   if (socket_print(socket, "#list\n") < 0) {
-    socket_setError(socket, "RSYNC: #list command failed -- %s\n", STRERROR);
+    socket_setError(socket, "RSYNC: #list command failed -- %s", STRERROR);
     return FALSE;
   }
 
   /* Read response: discard list output and check that we've received successful exit */
   do {
     if (! socket_readln(socket, buf, sizeof(buf))) {
-      socket_setError(socket, "RSYNC: error receiving data -- %s\n", STRERROR);
+      socket_setError(socket, "RSYNC: error receiving data -- %s", STRERROR);
       return FALSE;
     }
     Str_chomp(buf);
   } while (strncasecmp(buf, rsyncd, strlen(rsyncd)));
   if (strncasecmp(buf, rsyncd_exit, strlen(rsyncd_exit)) != 0) {
-    socket_setError(socket, "RSYNC: server sent unexpected response -- %s\n", buf);
+    socket_setError(socket, "RSYNC: server sent unexpected response -- %s", buf);
     return FALSE;
   }
 
