@@ -19,27 +19,21 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 #include "config.h"
 
-#include <ctype.h>
-
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
 
-#ifdef HAVE_ERRNO_H
-#include <errno.h>
-#endif
-
 #include "protocol.h"
 
 /**
  *  A simple 'SSH protocol version exchange' implemetation based on
  *  RFC (http://www.openssh.com/txt/draft-ietf-secsh-transport-14.txt)
- * 
+ *
  *  @file
  */
 int check_ssh(Socket_T socket) {
@@ -49,18 +43,18 @@ int check_ssh(Socket_T socket) {
   ASSERT(socket);
 
   if(!socket_readln(socket, buf, sizeof(buf))) {
-    socket_setError(socket, "SSH: error receiving identification string -- %s\n", STRERROR);
+    socket_setError(socket, "SSH: error receiving identification string -- %s", STRERROR);
     return FALSE;
   }
 
   if(! Str_startsWith(buf, "SSH-")) {
-    socket_setError(socket, "SSH: protocol error %s\n", buf);
+    socket_setError(socket, "SSH: protocol error %s", buf);
     return FALSE;
   }
 
   /* send identification string back to server */
   if(socket_write(socket, buf, strlen(buf)) <= 0) {
-    socket_setError(socket, "SSH: error sending identification string -- %s\n", STRERROR);
+    socket_setError(socket, "SSH: error sending identification string -- %s", STRERROR);
     return FALSE;
   }
 
