@@ -138,7 +138,7 @@ static void open_server(SendMail_T *S) {
         }
         do {
                 /* wait with ssl-connect if SSL_VERSION_TLSV1 is set (rfc2487) */
-                if (! S->ssl.use_ssl || S->ssl.version == SSL_VERSION_TLSV1)
+                if (! S->ssl.use_ssl || S->ssl.version == SSL_VERSION_TLSV1 || S->ssl.version == SSL_VERSION_TLSV11 || S->ssl.version == SSL_VERSION_TLSV12)
                         S->socket = socket_new(S->server, S->port, SOCKET_TCP, FALSE, Run.mailserver_timeout);
                 else
                         S->socket = socket_create_t(S->server, S->port, SOCKET_TCP, S->ssl, Run.mailserver_timeout);
@@ -208,10 +208,10 @@ int sendmail(Mail_T mail) {
                 Time_gmtstring(Time_now(), now);
                 snprintf(S.localhost, sizeof(S.localhost), "%s", Run.mail_hostname ? Run.mail_hostname : Run.system->name);
                 do_status(&S);
-                do_send(&S, "%s %s\r\n", ((S.ssl.use_ssl && S.ssl.version == SSL_VERSION_TLSV1) || S.username) ? "EHLO" : "HELO", S.localhost); // Use EHLO if TLS or Authentication is requested
+                do_send(&S, "%s %s\r\n", ((S.ssl.use_ssl && (S.ssl.version == SSL_VERSION_TLSV1 || S.ssl.version == SSL_VERSION_TLSV11 || S.ssl.version == SSL_VERSION_TLSV12)) || S.username) ? "EHLO" : "HELO", S.localhost); // Use EHLO if TLS or Authentication is requested
                 do_status(&S);
                 /* Switch to TLS now if configured */
-                if (S.ssl.use_ssl && S.ssl.version == SSL_VERSION_TLSV1) {
+                if (S.ssl.use_ssl && (S.ssl.version == SSL_VERSION_TLSV1 || S.ssl.version == SSL_VERSION_TLSV11 || S.ssl.version == SSL_VERSION_TLSV12)) {
                         do_send(&S, "STARTTLS\r\n");
                         do_status(&S);
                         if (! socket_switch2ssl(S.socket, S.ssl)) {
@@ -283,11 +283,11 @@ int sendmail(Mail_T mail) {
                         do_send(&S, "To: %s\r\n", m->to);
                         do_send(&S, "Subject: %s\r\n", m->subject);
                         do_send(&S, "Date: %s\r\n", now);
-                        do_send(&S, "X-Mailer: %s %s\r\n", prog, VERSION);
+                        do_send(&S, "X-Mailer: Monit %s\r\n", VERSION);
                         do_send(&S, "MIME-Version: 1.0\r\n");
                         do_send(&S, "Content-Type: text/plain; charset=\"iso-8859-1\"\r\n");
                         do_send(&S, "Content-Transfer-Encoding: 8bit\r\n");
-                        do_send(&S, "Message-Id: <%ld.%lu@%s>\r\n", time(NULL), random(), S.localhost);
+                        do_send(&S, "Message-Id: <%ld.%lu@%s>\r\n", (long)time(NULL), random(), S.localhost);
                         do_send(&S, "\r\n");
                         do_send(&S, "%s\r\n", m->message);
                         do_send(&S, ".\r\n");
